summaryrefslogtreecommitdiff
path: root/gnuradio-runtime/python/gnuradio/gr/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'gnuradio-runtime/python/gnuradio/gr/__init__.py')
-rw-r--r--gnuradio-runtime/python/gnuradio/gr/__init__.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/gnuradio-runtime/python/gnuradio/gr/__init__.py b/gnuradio-runtime/python/gnuradio/gr/__init__.py
index a1c1d3f397..2217907222 100644
--- a/gnuradio-runtime/python/gnuradio/gr/__init__.py
+++ b/gnuradio-runtime/python/gnuradio/gr/__init__.py
@@ -16,19 +16,19 @@ from __future__ import absolute_import
from __future__ import unicode_literals
# This is the main GNU Radio python module.
# We pull the swig output and the other modules into the gnuradio.gr namespace
# If gnuradio is installed then the swig output will be in this directory.
# Otherwise it will reside in ../../../swig.
import os, sys
try:
- from .runtime_swig import *
+ from .gr_python import *
except ImportError:
dirname, filename = os.path.split(os.path.abspath(__file__))
- __path__.append(os.path.join(dirname, "..", "..", "..", "swig"))
- from .runtime_swig import *
+ __path__.append(os.path.join(dirname, "bindings"))
+ from .gr_python import *
from .exceptions import *
from .top_block import *
@@ -36,8 +36,8 @@ from .hier_block2 import *
from .tag_utils import *
from .gateway import basic_block, sync_block, decim_block, interp_block, py_io_signature
-# Force the preference database to be initialized
-prefs = prefs.singleton
+# # Force the preference database to be initialized
+# prefs = prefs.singleton
log = gr.logger("log")
log.set_level(prefs().get_string("LOG", "log_level", "notset"))
@@ -16,19 +16,19 @@ from __future__ import absolute_import
from __future__ import unicode_literals
# This is the main GNU Radio python module.
-# We pull the swig output and the other modules into the gnuradio.gr namespace
+# We pull the pybind output and the other modules into the gnuradio.gr namespace
-# If gnuradio is installed then the swig output will be in this directory.
-# Otherwise it will reside in ../../../swig.
+# If gnuradio is installed then the pybind output will be in this directory.
+# Otherwise it will reside in bindings/.
import os, sys
try: